@@ -46,6 +46,8 @@ from saunter.SaunterWebDriver import SaunterWebDriver
 import py.test
 from _pytest.mark import MarkInfo
 
+from saunter.matchers import Matchers
+
 capabilities_map = {
     "firefox": DesiredCapabilities.FIREFOX,
     "internet explorer": DesiredCapabilities.INTERNETEXPLORER,
@@ -120,6 +122,9 @@ class SaunterTestCase(BaseTestCase):
             command_executor = "http://%s:%s/wd/hub" % (self.cf.get("Selenium", "server_host"), self.cf.get("Selenium", "server_port"))
         self.driver = WebDriver(desired_capabilities = desired_capabilities, command_executor = command_executor)
 
+        self.verificationErrors = []
+        self.matchers = Matchers(self.driver, self.verificationErrors)
+        
         if self.cf.getboolean("Saunter", "use_implicit_wait"):
             self.driver.implicitly_wait(self.cf.getint("Saunter", "implicit_wait"))
         
@@ -136,43 +141,7 @@ class SaunterTestCase(BaseTestCase):
             self.driver.quit()
 
         if hasattr(self, "cf") and self.cf.getboolean("SauceLabs", "ondemand"):
-            # session couldn't be established for some reason
-            if not hasattr(self, "sauce_session"):
-               return
-            sauce_session = self.sauce_session
-
-            j = {}
-
-            # name
-            j["name"] = self._testMethodName
-
-            # result
-            if self._resultForDoCleanups._excinfo == None and not self.verificationErrors:
-                # print("pass")
-                j["passed"] = True
-            else:
-                # print("fail")
-                j["passed"] = False
-
-            # tags
-            j["tags"] = []
-            for keyword in self._resultForDoCleanups.keywords:
-                if isinstance(self._resultForDoCleanups.keywords[keyword], MarkInfo):
-                    j["tags"].append(keyword)
-
-            # update
-            which_url = "https://saucelabs.com/rest/v1/%s/jobs/%s" % (self.cf.get("SauceLabs", "username"), sauce_session)
-            r = requests.put(which_url,
-                             data=json.dumps(j),
-                             headers={"Content-Type": "application/json"},
-                             auth=(self.cf.get("SauceLabs", "username"), self.cf.get("SauceLabs", "key")))
-            r.raise_for_status()
-
-            if self.cf.getboolean("SauceLabs", "get_video"):
-                self.fetch_sauce_artifact("video.flv")
-
-            if self.cf.getboolean("SauceLabs", "get_log"):
-                self.fetch_sauce_artifact("selenium-server.log")
+            self._saucelabs(method)
                 
     # def fetch_artifact(session, which):
     #     which_url = "https://saucelabs.com/rest/%s/jobs/%s/results/%s" % (self.cf.get("SauceLabs", "username"), session, which)
